@@ -1,29 +1,24 @@
 use cargo::util::command_prelude::ArgMatchesExt;
 use cargo::CliResult;
-use cargo::Config;
+use cargo::GlobalContext;
 
 use cargo_c::build::*;
-use cargo_c::cli::subcommand_build;
-
-use structopt::clap::*;
+use cargo_c::cli::{main_cli, run_cargo_fallback, subcommand_build};
+use cargo_c::config::*;
 
 fn main() -> CliResult {
-    let mut config = Config::default()?;
+    let mut config = GlobalContext::default()?;
 
     let subcommand = subcommand_build("cbuild", "Build the crate C-API");
-
-    let mut app = app_from_crate!()
-        .settings(&[
-            AppSettings::UnifiedHelpMessage,
-            AppSettings::DeriveDisplayOrder,
-            AppSettings::VersionlessSubcommands,
-        ])
-        .subcommand(subcommand);
+    let mut app = main_cli().subcommand(subcommand);
 
     let args = app.clone().get_matches();
 
     let subcommand_args = match args.subcommand() {
-        ("cbuild", Some(args)) => args,
+        Some(("cbuild", args)) => args,
+        Some((cmd, args)) => {
+            return run_cargo_fallback(cmd, args);
+        }
         _ => {
             // No subcommand provided.
             app.print_help()?;
@@ -31,16 +26,16 @@ fn main() -> CliResult {
         }
     };
 
-    if subcommand_args.is_present("version") {
+    if subcommand_args.flag("version") {
         println!("{} {}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
         return Ok(());
     }
 
-    config_configure(&mut config, subcommand_args)?;
+    global_context_configure(&mut config, subcommand_args)?;
 
     let mut ws = subcommand_args.workspace(&config)?;
 
-    let _ = cbuild(&mut ws, &config, &subcommand_args, "dev")?;
+    let _ = cbuild(&mut ws, &config, subcommand_args, "dev", false)?;
 
     Ok(())
 }
